==> breeze_website_builder_5.4.54.tar.gz: manage/edit_head_select.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created:	11/28/2013	ELL
// Revised: 11/21/2014	ELL
// Off-loaded JavaScript.
// 

	include ("check_session.php");
	
	$last_head_edited = $_SESSION['last_head_edited'];
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Edit Head Select</title>
<link rel="stylesheet" href="manager.css" type="text/css">

<script language="javascript" type="text/javascript" src="js/edit_head_select.js"></script>

</head>

<body>
<div id="sub_level_1_buttons">

          <div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1">Edit Head Code</div><div class="button_heading_help" onclick="OpenHelpWindow();">&nbsp;</div></div>
		    <?php
			$query = "SELECT head_name FROM " . BWB_TABLE_PREFIX . "head";
			$result = $bwb_dbh->query($query);
			while($row = $result->fetch(PDO::FETCH_ASSOC))
			{
				$head_name = $row["head_name"];

				if ($head_name == $last_head_edited)
					$selected = " down_sub";
				else
					$selected = "";
					
				echo "<div class='button_sub_level_1$selected' onClick=\"window.location='edit_head.php?head_name=$head_name';\"><span class='button_text_sub_level_1'>$head_name</span></div>\n";
			}
		?>
      
</div>
</body>
</html>

==> breeze_website_builder_6.1.20.tar.gz: manage/edit_head_select.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created:	11/28/2013	ELL
// Revised: 11/21/2014	ELL
// Off-loaded JavaScript.
// 

	include ("check_session.php");
	
	$last_head_edited = $_SESSION['last_head_edited'];
?>

<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Edit Head Select | Breeze Website Builder</title>
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">

<script language="javascript" type="text/javascript" src="js/edit_head_select.js"></script>

</head>

<body>
<div id="sub_level_1_buttons">

          <div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo EDIT_HEAD_SELECT_HEADING; ?></div><div class="button_heading_help" onclick="OpenHelpWindow();">&nbsp;</div></div>
		    <?php
			$query = "SELECT head_name FROM " . BWB_TABLE_PREFIX . "head ORDER BY head_name";
			$result = $bwb_dbh->query($query);
			while($row = $result->fetch(PDO::FETCH_ASSOC))
			{
				$head_name = $row["head_name"];

				if ($head_name == $last_head_edited)
					$selected = " down_sub";
				else
					$selected = "";
					
				echo "<div class='button_sub_level_1$selected' onClick=\"window.location='edit_head.php?head_name=$head_name';\"><span class='button_text_sub_level_1'>$head_name</span></div>\n";
			}
		?>
      
</div>
</body>
</html>
